<?php
/* $Id: french-iso-8859-15.inc.php 10490 2007-07-16 13:08:28Z lem9 $ */

$charset = 'iso-8859-15';
$text_dir = 'ltr';
$number_thousands_separator = '';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('o', 'Kio', 'Mio', 'Gio', 'Tio', 'Pio', 'Eio');

$mysql_5_0_doc_lang = 'fr';

$day_of_week = array('Dim', 'Lun', 'Mar', 'Mer', 'Jeu', 'Ven', 'Sam');
$month = array('Janvier', 'Fvrier', 'Mars', 'Avril', 'Mai', 'Juin', 'Juillet', 'Aot', 'Septembre', 'Octobre', 'Novembre', 'Dcembre');
// Voir http://www.php.net/manual/en/function.strftime.php pour la variable
// ci-dessous
$datefmt = '%A %d %B %Y  %H:%M';

$timespanfmt = '%s jours, %s heures, %s minutes et %s secondes';

$strAbortedClients = 'Arrts prmaturs';
$strAccessDenied = 'Accs refus';
$strAccessDeniedCreateConfig = 'La raison probable est que vous n\'avez pas cr de fichier de configuration. Vous pouvez utiliser le %1$sscript de configuration%2$s dans ce but.';
$strAccessDeniedExplanation = 'phpMyAdmin a tent de se connecter au serveur MySQL, et le serveur a rejet la connexion. Veuillez vrifier les valeurs de "host", "username" et "password" dans votre configuration et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
$strAction = 'Action';
$strAddAutoIncrement = 'Inclure la valeur courante de l\'AUTO_INCREMENT';
$strAddClause = 'Ajouter %s';
$strAddConstraints = 'Inclure les contraintes de cls trangres';
$strAddDeleteColumn = 'Ajouter/effacer x colonne(s)';
$strAddDeleteRow = 'Ajouter/effacer x ligne(s)';
$strAddFields = 'Ajouter %s champ(s)';
$strAddHeaderComment = 'Commentaires mis en en-tte (\\n spare les lignes)';
$strAddIntoComments = 'Inclure sous forme de commentaires';
$strAddNewField = 'Ajouter un champ';
$strAddPrivilegesOnDb = 'Ajouter des privilges sur cette base de donnes';
$strAddPrivilegesOnTbl = 'Ajouter des privilges sur cette table';
$strAddSearchConditions = 'Critres de recherche (pour l\'nonc "where"):';
$strAddToIndex = 'Ajouter  la clef&nbsp;%s&nbsp;colonne(s)';
$strAddUser = 'Ajouter un utilisateur';
$strAddUserMessage = 'Vous avez ajout un utilisateur';
$strAdministration = 'Administration';
$strAffectedRows = 'Nombre d\'enregistrements affects :';
$strAfter = 'Aprs %s';
$strAfterInsertBack = 'Retourner  la page prcdente';
$strAfterInsertNewInsert = 'Insrer un nouvel enregistrement';
$strAfterInsertNext = 'Modifier l\'enregistrement suivant';
$strAfterInsertSame = 'Demeurer sur cette page';
$strAllowInterrupt = 'Permettre l\'interruption de l\'importation si la limite de temps est sur le point d\'tre atteinte. Ceci pourrait aider  importer des fichiers volumineux, au dtriment du respect des transactions.';
$strAllTableSameWidth = 'Afficher toutes les tables avec une largeur identique';
$strAll = 'Tout';
$strAlterOrderBy = '<b>Ordonner</b> la table par';
$strAnalyzeTable = 'Analyser la table';
$strAnd = 'et';
$strAndThen = 'et ensuite';
$strAngularLinks = 'Liens angulaires';
$strAnIndex = 'Un index a t ajout sur %s';
$strAnyHost = 'Tout serveur';
$strAny = 'N\'importe quel';
$strAnyUser = 'Tout utilisateur';
$strApproximateCount = 'Peut tre approximatif. Voir FAQ 3.11';
$strAPrimaryKey = 'Une cl primaire a t ajoute sur %s';
$strArabic = 'arabe';
$strArmenian = 'armnien';
$strAscending = 'Croissant';
$strAtBeginningOfTable = 'En dbut de table';
$strAtEndOfTable = 'En fin de table';
$strAttr = 'Attributs';
$strAutomaticLayout = 'Mise en page automatique';

$strBack = 'Retour';
$strBaltic = 'baltique';
$strBeginCut = 'Dbut de la section  couper';
$strBeginRaw = 'Dbut des informations sur l\'anomalie';
$strBinary = 'Binaire';
$strBinaryDoNotEdit = 'Binaire - ne pas diter';
$strBinaryLog = 'Log binaire';
$strBinLogEventType = 'Type d\'vnement';
$strBinLogInfo = 'Information';
$strBinLogName = 'Nom du log binaire';
$strBinLogOriginalPosition = 'Position d\'origine';
$strBinLogPosition = 'Position';
$strBinLogServerId = 'ID du serveur';
$strBookmarkAllUsers = 'Signet visible pour les autres utilisateurs';
$strBookmarkCreated = 'Signet %s cr';
$strBookmarkDeleted = 'Le signet a t effac.';
$strBookmarkLabel = 'Intitul';
$strBookmarkQuery = 'Requtes en signets';
$strBookmarkReplace = 'Remplacer un signet existant du mme nom';
$strBookmarkThis = 'Conserver cette requte dans les signets';
$strBookmarkView = 'Voir uniquement';
$strBrowse = 'Afficher';
$strBrowseDistinctValues = 'Affiche les valeurs distinctes';
$strBrowseForeignValues = 'Afficher les valeurs de la table lie';
$strBufferPoolActivity = 'Activit de la mmoire-tampon';
$strBufferPool = 'Mmoire-tampon';
$strBufferPoolUsage = 'Utilisation de la mmoire-tampon';
$strBufferReadMissesInPercent = 'Lectures non-satisfaites en %';
$strBufferReadMisses = 'Lectures non-satisfaites';
$strBufferWriteWaitsInPercent = 'Nombre d\'attentes d\'criture en %';
$strBufferWriteWaits = 'Nombre d\'attentes d\'criture';
$strBulgarian = 'bulgare';
$strBusyPages = 'Pages occupes';
$strBzError = 'phpMyAdmin n\'a pu compresser le fichier export en raison d\'une composante Bz2 dfaillante dans cette version de PHP. Il est recommand de donner  <code>$cfg[\'BZipDump\']</code> dans votre fichier de configuration phpMyAdmin la valeur <code>FALSE</code>. Si vous voulez utiliser la compression en mode Bz2, veuillez mettre  niveau votre version de PHP. Ce rapport d\'anomalies PHP donne les dtails: %s.';
$strBzip = '"bzipp"';

$strCalendar = 'Calendrier';
$strCancel = 'Annuler';
$strCanNotLoadExportPlugins = 'Erreur lors du chargement des modules d\'exportation!';
$strCanNotLoadImportPlugins = 'Chargement impossible des greffons d\'importation, veuillez vrifier votre installation!';
$strCannotLogin = 'Connexion au serveur MySQL non permise';
$strCantLoad = 'PHP ne peut charger l\'extension %s, [br]veuillez vrifier votre configuration de PHP';
$strCantLoadRecodeIconv = 'Erreur lors du chargement de l\'extension iconv ou recode, utilise pour convertir le jeu de caractres; veuillez activer l\'une de ces extensions dans PHP, ou dsactiver la conversion des jeux de caractres dans phpMyAdmin';
$strCantRenameIdxToPrimary = 'La clef ne peut tre renomme PRIMARY&nbsp;!';
$strCantUseRecodeIconv = 'Erreur lors de l\'utilisation de iconv, libiconv et recode_string, alors que ces extensions semblent charges. Veuillez vrifier votre configuration de PHP.';
$strCardinality = 'Cardinalit';
$strCaseInsensitive = 'insensible  la casse';
$strCaseSensitive = 'sensible  la casse';
$strCentralEuropean = 'Europe centrale';
$strChangeCopyModeCopy = '... conserver intact l\'ancien utilisateur.';
$strChangeCopyMode = 'Crer un nouvel utilisateur avec les mmes privilges et ...';
$strChangeCopyModeDeleteAndReload = ' ... supprimer l\'ancien utilisateur, puis recharger les privilges au serveur.';
$strChangeCopyModeJustDelete = ' ... supprimer l\'ancien utilisateur.';
$strChangeCopyModeRevoke = ' ... effacer tous les privilges de l\'ancien utilisateur, puis l\'effacer.';
$strChangeCopyUser = 'Changement des informations de connexion / Copie d\'utilisateur';
$strChangeDisplay = 'Champ  afficher';
$strChange = 'Modifier';
$strChangePassword = 'Modifier le mot de passe';
$strCharset = 'Jeu de caractres';
$strCharsetOfFile = 'Jeu de caractres du fichier:';
$strCharsetsAndCollations = 'Jeux de caractres et interclassement';
$strCharsets = 'Jeux de caractres';
$strCheckAll = 'Tout cocher';
$strCheckOverhead = 'Cocher tables avec pertes';
$strCheckPrivsLong = 'Vrifier les privilges pour la base de donnes &quot;%s&quot;.';
$strCheckPrivs = 'Vrifier les privilges';
$strCheckTable = 'Vrifier la table';
$strChoosePage = 'Page  diter';
$strColComFeat = 'Commentaires de colonnes';
$strCollation = 'Interclassement';
$strColumnNames = 'Nom des colonnes';
$strColumnPrivileges = 'Privilges de colonnes';
$strCommand = 'Commande';
$strComments = 'Commentaires';
$strCommentsForTable = 'COMMENTAIRES POUR LA TABLE';
$strCompatibleHashing = 'compatible MySQL&nbsp;4.0';
$strCompleteInserts = 'Insertions compltes';
$strCompression = 'Compression';
$strCompressionWillBeDetected = 'Ces modes de compression seront dtects automatiquement : %s';
$strConfigDefaultFileError = 'Chargement de la configuration par dfaut impossible depuis "%1$s"';
$strConfigFileError = 'phpMyAdmin n\'a pu lire votre fichier de configuration!<br />Il est possible qu\'il contienne une erreur de syntaxe, ou que PHP soit incapable de le trouver<br /> l\'aide du lien suivant, vous pouvez vrifier le message d\'erreur gnr par PHP;<br />la plupart du temps, un apostrophe ou un point-virgule sont manquants.<br />Si vous recevez une page blanche, aucune erreur n\'a t dtecte.';
$strConfigureTableCoord = 'Les coordonnes de la table %s n\'ont pas t configures';
$strConnectionError = 'Connexion impossible: rglages incorrects.';
$strConnections = 'Connexions';
$strConstraintsForDumped = 'Contraintes pour les tables exportes';
$strConstraintsForTable = 'Contraintes pour la table';
$strControluserFailed = 'La connexion au "controluser" tel que dfini dans votre configuration a chou.';
$strCookiesRequired = 'Vous devez accepter les cookies pour poursuivre.';
$strCopy = 'Copier';
$strCopyDatabaseOK = 'La base de donnes %s a t copie sur %s';
$strCopyTable = '<b>Copier</b> la table vers (base<b>.</b>table)&nbsp;:';
$strCopyTableOK = 'La table %s a t copie vers %s.';
$strCopyTableSameNames = 'On ne peut copier la table sur elle-mme!';
$strCouldNotKill = 'phpMyAdmin n\'a pu liminer le processus %s. Il tait probablement dj ferm.';
$strCreate = 'Crer';
$strCreateDatabaseBeforeCopying = 'Faire CREATE DATABASE avant la copie';
$strCreateIndex = 'Crer une clef sur&nbsp;%s&nbsp;colonne(s)';
$strCreateIndexTopic = 'Crer un nouvelle clef';
$strCreateNewDatabase = 'Crer une base de donnes';
$strCreateNewTable = '<b>Crer une nouvelle table</b> sur la base %s';
$strCreatePage = 'Crer une page';
$strCreatePdfFeat = 'Gnration de schmas en PDF';
$strCreateRelation = 'Nouvelle relation';
$strCreateTable  = 'Nouvelle table';
$strCreateUserDatabase = 'Base de donnes pour cet utilisateur';
$strCreateUserDatabaseName = 'Crer une base portant son nom et donner  cet utilisateur tous les privilges sur cette base';
$strCreateUserDatabaseNone = 'Aucune';
$strCreateUserDatabaseWildcard = 'Donner les privilges passepartout ("%")';
$strCreationDates = 'Dates de cration/modification/vrification';
$strCriteria = 'Critre';
$strCroatian = 'croate';
$strCSV = 'CSV';
$strCyrillic = 'cyrillique';
$strCzechSlovak = 'tchque-slovaque';
$strCzech = 'tchque';

$strDanish = 'danois';
$strDatabase = 'Base de donnes';
$strDatabaseEmpty = 'Le nom de la base de donnes est vide!';
$strDatabaseExportOptions = 'Options d\'exportation';
$strDatabaseHasBeenDropped = 'La base de donnes %s a t efface.';
$strDatabases = 'Bases de donnes';
$strDatabasesDropped = '%s bases de donnes ont t supprimes.';
$strDatabasesStatsDisable = 'Dsactiver les statistiques';
$strDatabasesStatsEnable = 'Activer les statistiques';
$strDatabasesStatsHeavyTraffic = 'Note: L\'activation des statistiques peut causer un trafic important entre le serveur web et le serveur MySQL.';
$strDatabasesStats = 'Statistiques sur les bases de donnes';
$strDataDict = 'Dictionnaire de donnes';
$strData = 'Donnes';
$strDataOnly = 'Donnes seulement';
$strDataPages = 'Pages contenant des donnes';
$strDBComment = '<b>Commentaire</b> sur la base de donnes: ';
$strDBCopy = 'Copier la base de donnes vers';
$strDbIsEmpty = 'La base de donnes semble vide!';
$strDbPrivileges = 'Privilges spcifiques  une base de donnes';
$strDBRename = '<b>Changer le nom</b> de la base de donnes pour';
$strDbSpecific = 'spcifique  cette base de donnes';
$strDefault = 'Dfaut';
$strDefaultEngine = 'Sur ce serveur MySQL, le moteur de stockage par dfaut est %s.';
$strDefaultValueHelp = 'Pour les valeurs par dfaut, veuillez n\'entrer qu\'une seule valeur, sans caractre d\'chappement ou apostrophes, sous la forme: a';
$strDefragment = 'Dfragmenter la table';
$strDelayedInserts = 'Insertions avec dlais (DELAYED)';
$strDeleteAndFlushDescr = 'Ceci est la mthode la plus directe, mais le fait de recharger les privilges pourrait prendre du temps.';
$strDeleteAndFlush = 'Effacer les utilisateurs, puis recharger les privilges.';
$strDeleted = 'L\'enregistrement a t effac';
$strDeletedRows = 'Nombre d\'enregistrements effacs :';
$strDelete = 'Effacer';
$strDeleteNoUsersSelected = 'Aucun utilisateur n\'a t choisi en vue de le dtruire!';
$strDeleteRelation = 'Effacer la relation';
$strDeleting = 'Destruction de %s';
$strDelimiter = 'Dlimiteur';
$strDelOld = 'Cette page fait rfrence  des tables qui n\'existent plus. Voulez-vous effacer ces rfrences?';
$strDescending = 'Dcroissant';
$strDescription = 'Description';
$strDesigner = 'Concepteur';
$strDesignerHelpDisplayField = 'Le champ  afficher est montr en rose. Pour indiquer qu\'un champ est ou n\'est plus le champ  afficher, cliquer l\'icne "Champ  afficher", puis cliquer sur le nom de champ appropri.';
$strDictionary = 'dictionnaire';
$strDirectLinks = 'Liens directs';
$strDirtyPages = 'Pages modifies';
$strDisabled = 'dsactiv';
$strDisableForeignChecks = 'Dsactiver la vrification des cls trangres';
$strDisplayFeat = 'Affichage infobulle';
$strDisplayOrder = 'Ordre d\'affichage :';
$strDisplayPDF = '<b>Afficher le schma</b> en PDF';
$strDoAQuery = 'Recherche par valeur (passepartout: "%")';
$strDocSQL = 'DocSQL';
$strDocu = 'Documentation';
$strDoYouReally = 'Voulez-vous vraiment effectuer ';
$strDropDatabaseStrongWarning = 'Vous tes sur le point de DTRUIRE une base de donnes!';
$strDrop = 'Supprimer';
$strDropUsersDb = 'Supprimer les bases de donnes portant le mme nom que les utilisateurs';
$strDumpingData = 'Contenu de la table';
$strDumpSaved = 'Le fichier d\'exportation a t sauvegard sous %s.';
$strDumpXRows = 'Exporte %s enregistrement(s)  partir du rang n %s.';
$strDynamic = 'dynamique';

$strEdit = 'Modifier';
$strEditPDFPages = 'Prparer le schma en PDF';
$strEditPrivileges = 'Changer les privilges';
$strEffective = 'effectif';
$strEmptyResultSet = 'MySQL n\'a retourn aucun enregistrement.';
$strEmpty = 'Vider';
$strEnabled = 'activ';
$strEncloseInTransaction = 'Utiliser le mode transactionnel';
$strEndCut = 'Fin de la section  couper';
$strEnd = 'Fin';
$strEndRaw = 'Fin des informations sur l\'anomalie';
$strEngineAvailable = '%s est disponible sur ce serveur MySQL.';
$strEngineDisabled = '%s a t dsactiv sur ce serveur MySQL.';
$strEngines = 'Moteurs';
$strEngineUnsupported = 'Ce serveur MySQL ne supporte pas le moteur de stockage %s.';
$strEnglish = 'anglais';
$strEnglishPrivileges = ' Veuillez noter que les noms de privilges sont exprims en anglais';
$strError = 'Erreur';
$strErrorInZipFile = 'Erreur rencontre dans l\'archive ZIP :';
$strErrorRelationAdded = 'Erreur: relation non ajoute.';
$strErrorRelationExists = 'Erreur: relation dj existante.';
$strErrorRenamingTable = 'Erreur lors du renommage de %1$s en %2$s';
$strErrorSaveTable = 'Erreur lors de la sauvegarde des coordonnes Concepteur.';
$strEscapeWildcards = 'Prfixer avec \ les passepartouts _ et % pour un usage littral';
$strEsperanto = 'Espranto';
$strEstonian = 'estonien';
$strEvent = 'vnement';
$strExcelEdition = 'Excel en version';
$strExecuteBookmarked = 'Excuter la requte en signets';
$strExplain = 'Expliquer SQL';
$strExport = 'Exporter';
$strExportImportToScale = 'Exporter/Importer  l\'chelle';
$strExportMustBeFile = 'Ce choix d\'exportation doit tre sauvegard dans un fichier!';
$strExtendedInserts = 'Insertions tendues';
$strExtra = 'Extra';

$strFailedAttempts = 'Tentatives choues';
$strField = 'Champ';
$strFieldHasBeenDropped = 'Le champ %s a t effac';
$strFieldInsertFromFileTempDirNotExists = 'Erreur lors du dplacement du fichier tlcharg, voir FAQ 1.11';
$strFields = 'Champs';
$strFieldsEnclosedBy = 'Champs entours par';
$strFieldsEscapedBy = 'Caractre spcial';
$strFieldsTerminatedBy = 'Champs termins par';
$strFileAlreadyExists = 'Le fichier %s existe dj sur le serveur, veuillez changer le nom, ou cocher l\'option craser';
$strFileCouldNotBeRead = 'Le fichier n\'a pu tre lu';
$strFileNameTemplateDescription = 'Cette valeur est interprte avec %1$sstrftime%2$s, vous pouvez donc utiliser des chanes de format d\'heure. Ces transformations additionnelles vont se produire: %3$s. Tout autre texte sera conserv tel quel.';
$strFileNameTemplateDescriptionDatabase = 'nom de base de donnes';
$strFileNameTemplateDescriptionServer = 'nom de serveur';
$strFileNameTemplateDescriptionTable = 'nom de table';
$strFileNameTemplate = 'Modle de nom de fichier';
$strFileNameTemplateRemember = 'se souvenir du modle';
$strFiles = 'Fichiers';
$strFileToImport = 'Fichier  importer';
$strFixed = 'fixe';
$strFlushPrivilegesNote = 'Note: phpMyAdmin obtient la liste des privilges directement  partir des tables MySQL. Le contenu de ces tables peut tre diffrent des privilges effectifs, si des changements manuels ont t apports. Dans ce cas, vous devriez %srecharger les privilges%s avant de continuer.';
$strFlushQueryCache = 'Vider la cache des requtes';
$strFlushTable = 'Recharger la table ("FLUSH")';
$strFlushTables = 'Fermer toutes les tables';
$strFontSize = 'Taille du texte';
$strForeignKeyError = 'Erreur lors de la cration de la cl trangre (vrifiez les types de donnes';
$strFormat = 'format';
$strFormEmpty = 'Formulaire incomplet !';
$strFreePages = 'Pages libres';
$strFullText = 'Textes complets';
$strFunction = 'Fonction';
$strFunctions = 'Fonctions';

$strGenBy = 'Gnr par';
$strGeneralRelationFeat = 'Fonctions relationnelles';
$strGenerate = 'Gnrer'; 
$strGeneratePassword = 'Gnrer un mot de passe';
$strGenTime = 'Gnr le ';
$strGeorgian = 'gorgien';
$strGerman = 'allemand';
$strGlobal = 'global';
$strGlobalPrivileges = 'Privilges globaux';
$strGlobalValue = 'Valeur globale';
$strGo = 'Excuter';
$strGrantOption = '"Grant"';
$strGreek = 'grec';
$strGzip = '"gzipp"';

$strHandler = 'Gestionnaire';
$strHasBeenAltered = 'a t modifi(e).';
$strHasBeenCreated = 'a t cr(e).';
$strHaveToShow = 'Vous devez choisir au moins une colonne  afficher';
$strHebrew = 'hbreu';
$strHelp = 'Aide';
$strHexForBLOB = 'Utiliser l\'hexadecimal pour les BLOB';
$strHide         = 'Cacher';
$strHideShowAll = 'Cacher/montrer tout';
$strHideShowNoRelation = 'Cacher/montrer les tables sans liens';
$strHome = 'Accueil';
$strHomepageOfficial = 'Site officiel de phpMyAdmin';
$strHostEmpty = 'Le nom de serveur est vide';
$strHost = 'Serveur';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHungarian = 'hongrois';

$strIcelandic = 'islandais';
$strId = 'ID';
$strIdxFulltext = 'Texte entier';
$strIEUnsupported = 'Fonction non disponible sous Internet Explorer.';
$strIgnoreDuplicates = 'Ignorer les doublons';
$strIgnore = 'Ignorer';
$strIgnoreInserts = 'Ignorer les erreurs de doublons (INSERT IGNORE)';
$strImportExportCoords = 'Importer/Exporter les coordonnes pour le schma PDF';
$strImportFiles = 'Importe les fichiers';
$strImportFormat = 'Format du fichier d\'importation';
$strImport = 'Importer';
$strImportSuccessfullyFinished = 'L\'importation s\'est termine avec succs, %d requtes excutes.';
$strIndexes = 'Index';
$strIndexesSeemEqual = 'Les index suivants semblent quivalents, vous devriez en liminer un.';
$strIndexHasBeenDropped = 'L\'index %s a t effac';
$strIndex = 'Index';
$strIndexName = 'Nom de la clef&nbsp;:';
$strIndexType = 'Type de clef&nbsp;:';
$strIndexWarningTable = 'Il y a des problmes avec les index de la table `%s`';
$strInnoDBAutoextendIncrement = 'Auto-croissant: Taille de l\'incrment';
$strInnoDBAutoextendIncrementDesc = 'La valeur de l\'incrment lors de l\'agrandissement du fichier auto-croissant lorsqu\'il devient plein.';
$strInnoDBBufferPoolSizeDesc = 'La taille de la mmoire-tampon utilise par InnoDB pour les oprations d\'antmoire sur les donnes et les index.';
$strInnoDBBufferPoolSize = 'Taille de la mmoire-tampon';
$strInnoDBDataFilePath = 'Fichiers de donnes';
$strInnoDBDataHomeDirDesc = 'Le chemin du rpertoire pour tous les fichiers de donnes InnoDB.';
$strInnoDBDataHomeDir = 'Rpertoire des donnes';
$strInnoDBPages = 'pages';
$strInnoDBRelationAdded = 'Relation InnoDB ajoute';
$strInnodbStat = 'tat InnoDB';
$strInsecureMySQL = 'Votre fichier de configuration fait rfrence  l\'utilisateur root sans mot de passe, ce qui correspond  la valeur par dfaut de MySQL.  Votre serveur MySQL est donc ouvert aux intrusions, et vous devriez corriger ce problme de scurit.';
$strInsertAsNewRow = 'Sauvegarder un nouvel enregistrement';
$strInsertedRowId = 'Identifiant de l\'enregistrement insr:';
$strInsertedRows = 'Nombre d\'enregistrements insrs :';
$strInsert = 'Insrer';
$strInternalNotNecessary = '* Si une relation existe dans InnoDB, il n\'est pas ncessaire de la dfinir dans les relations internes.';
$strInternalRelationAdded = 'Relation interne ajoute';
$strInternalRelations = 'Relations internes';
$strInUse = 'utilis';
$strInvalidAuthMethod = 'Le fichier de configuration contient un type d\'authentification invalide :';
$strInvalidColumnCount = 'Le nombre de champs doit tre plus grand que zro.';
$strInvalidColumn = 'La colonne %s est invalide!';
$strInvalidCSVFieldCount = 'Nombre de champs invalide dans les donnes CSV  la ligne %d';
$strInvalidCSVFormat = 'Format invalide pour les donnes CSV  la ligne %d.';
$strInvalidCSVParameter = 'Paramtres invalides pour l\'importation CSV: %s';
$strInvalidDatabase = 'Nom de base de donnes invalide';
$strInvalidFieldAddCount = 'Vous devez ajouter au moins un champ';
$strInvalidFieldCount = 'La table doit comporter au moins un champ';
$strInvalidLDIImport = 'Ce greffon ne supporte pas les importations en format comprim!';
$strInvalidRowNumber = '%d n\'est pas un numro d\'enregistrement valable.';
$strInvalidServerHostname = 'Nom d\'hte (hostname) invalide pour le serveur %1$s. Veuillez vrifier votre configuration.';
$strInvalidServerIndex = 'Indice de serveur invalide: "%s"';
$strInvalidTableName = 'Nom de table invalide';

$strJapanese = 'japonais';
$strJoins = 'Jointures';
$strJumpToDB = 'Aller  la base de donnes &quot;%s&quot;.';
$strJustDeleteDescr = 'Les utilisateurs &quot;effacs&quot; auront quand mme accs au serveur, jusqu\' ce que les privilges soient rechargs.';
$strJustDelete = 'Seulement effacer les utilisateurs des tables de privilges.';

$strKeepPass = 'Conserver le mot de passe';
$strKeyCache = 'Cache des cls';
$strKeyname = 'Nom de la cl';
$strKill = 'Supprimer';
$strKnownExternalBug = 'La fonctionnalit %s est affecte par une anomalie connue, voir %s';
$strKorean = 'coren';

$strLandscape = 'Paysage';
$strLanguage = 'Langue';
$strLanguageUnknown = 'Langue inconnue: %1$s.';
$strLatchedPages = 'Pages verrouilles';
$strLatexCaption = 'Sous-titre de la table';
$strLatexContent = 'Contenu de la table __TABLE__';
$strLatexContinuedCaption = 'Sous-titre de la table (suite)';
$strLatexContinued = '(suite)';
$strLatexIncludeCaption = 'Inclure les sous-titres';
$strLatexLabel = 'Cl de l\'tiquette';
$strLaTeX = 'LaTeX';
$strLatexStructure = 'Structure de la table __TABLE__';
$strLatvian = 'letton';
$strLDI = 'CSV via LOAD DATA';
$strLDILocal = 'Utiliser l\'option LOCAL';
$strLengthSet = 'Taille/Valeurs*';
$strLimitNumRows = 'Nombre d\'enregistrements par page';
$strLinesTerminatedBy = 'Lignes termines par';
$strLinkNotFound = 'Lien absent';
$strLinksTo = 'Reli ';
$strLithuanian = 'lituanien';
$strLocalhost = 'Local';
$strLocationTextfile = 'Emplacement du fichier texte';
$strLogin = 'Connexion';
$strLoginInformation = 'Information pour la connexion';
$strLogout = 'Quitter';
$strLogPassword = 'Mot de passe&nbsp;:';
$strLogServer = 'Serveur';
$strLogUsername = 'Nom d\'utilisateur&nbsp;:';
$strLongOperation = 'Cette opration pourrait tre longue. Procder quand mme? ';

$strMaxConnects = 'max. de connexions simultanes';
$strMaximalQueryLength = 'Taille maximum de la requte gnre';
$strMaximumSize = 'Taille maximum: %s%s';
$strMbExtensionMissing = 'L\'extension PHP mbstring n\'a pu tre localise et il semble que vous utilisiez un jeu de caractres multi-octets. Sans cette extension, phpMyAdmin est incapable de grer correctement les caractres et il peut en rsulter des problmes.'; 
$strMbOverloadWarning = 'Vous avez activ mbstring.func_overload dans votre configuration PHP. Cette option est incompatible avec phpMyAdmin et peut nuire au traitement des donnes!';
$strMIME_available_mime = 'Types MIME disponibles';
$strMIME_available_transform = 'Transformations disponibles';
$strMIME_description = 'Description';
$strMIME_MIMEtype = 'Type MIME';
$strMIME_nodescription = 'Aucune description n\'est disponible pour cette transformation.<br />Veuillez demander  son auteur, des dtails sur %s.';
$strMIME_transformation_note = 'La %sdescription des transformations%s explique les transformations possibles en fonction des types MIME.';
$strMIME_transformation_options_note = 'Veuillez entrer les valeurs des options de transformation en suivant ce format: \'a\', 100, b,\'c\'...<br />Si vous devez entrer un caractre ("\") ou une apostrophe ("\'") parmi ces valeurs, faites-le prcder du caractre d\'chappement, par exemple  \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_transformation_options = 'Options de transformation';
$strMIME_transformation = 'Transformation';
$strMIMETypesForTable = 'TYPES MIME POUR LA TABLE';
$strMIME_without = 'Les types MIME affiches en italiques ne possdent pas de fonctions de transformation.';
$strModifications = 'Les modifications ont t sauvegardes.';
$strModifyIndexTopic = 'Modifier une clef';
$strModify = 'Modifier';
$strMoveMenu = 'Dplacer le menu';
$strMoveTable = '<b>Dplacer</b> la table vers (base<b>.</b>table)&nbsp;:';
$strMoveTableOK = 'La table %s a t dplace vers %s.';
$strMoveTableSameNames = 'On ne peut dplacer la table sur elle-mme!';
$strMultilingual = 'multilingue';
$strMyISAMDataPointerSizeDesc = 'La taille du pointeur (en octets) qui servira lors d\'un CREATE TABLE sur une table MyISAM si aucune option MAX_ROWS n\'est indique';
$strMyISAMDataPointerSize = 'Taille du pointeur de donnes';
$strMyISAMMaxExtraSortFileSizeDesc = 'Si le fichier temporaire utilis pour la cration rapide des index MyISAM devrait s\'avrer plus volumineux que d\'employer la cache des cls (la diffrence tant spcifie ici), utiliser la mthode de cache des cls';
$strMyISAMMaxExtraSortFileSize = 'La taille maximum pour les fichiers temporaires utiliss lors de la cration d\'index';
$strMyISAMMaxSortFileSizeDesc = 'La taille maximum du fichier temporaire qu\'il est permis  MySQL d\'allouer pour recrer un index MyISAM (durant un REPAIR TABLE, ALTER TABLE ou LOAD DATA INFILE)';
$strMyISAMMaxSortFileSize = 'Taille maximum pour les fichiers de tri temporaires';
$strMyISAMRecoverOptionsDesc = 'Le mode de recouvrement automatique en cas de tables MyISAM en mauvais tat, tel que rgl via l\'option --myisam-recover au dpart du serveur';
$strMyISAMRecoverOptions = 'Mode de recouvrement automatique';
$strMyISAMRepairThreadsDesc = 'Si cette valeur est plus grande que 1, les index de tables MyISAM sont crs en parallle (chaque index dans son propre fil d\'excution) lors d\'une rparation.';
$strMyISAMRepairThreads = 'Nombre de fils d\'excution pour la rparation';
$strMyISAMSortBufferSizeDesc = 'La mmoire tampon qui est alloue pour trier les index MyISAM durant une opration REPAIR TABLE ou pour crer les index lors d\'un CREATE INDEX ou ALTER TABLE';
$strMyISAMSortBufferSize = 'Taille de la mmoire tampon';
$strMySQLCharset = 'Jeu de caractres pour MySQL';
$strMysqlClientVersion = 'Version du client MySQL';
$strMySQLConnectionCollation = 'Interclassement pour la connexion MySQL';
$strMysqlLibDiffersServerVersion = 'La version de votre bibliothque MySQL (%s) diffre de la version de votre serveur MySQL (%s). Ceci peut occasionner un comportement imprvisible.';
$strMySQLSaid = 'MySQL a rpondu:';
$strMySQLShowProcess = 'Afficher les processus';
$strMySQLShowStatus = 'Afficher l\'tat du serveur';
$strMySQLShowVars = 'Afficher les variables du serveur';

$strName = 'Nom';
$strNext = 'Suivant';
$strNoActivity = 'Aucune activit depuis %s secondes ou plus, veuillez vous reconnecter';
$strNoDatabases = 'Aucune base de donnes';
$strNoDatabasesSelected = 'Aucune base de donnes n\'a t slectionne.';
$strNoDataReceived = 'Aucune donnes n\'a t reu en vue de l\'importation. Aucun nom de fichier n\'a t fourni, ou encore la taille du fichier a dpass la limite permise par votre configuration de PHP. Voir FAQ 1.16';
$strNoDescription = 'pas de description';
$strNoDetailsForEngine = 'Aucune information dtaille sur l\'tat n\'est disponible pour ce moteur de stockage.';
$strNoDropDatabases = 'La commande "DROP DATABASE" est dsactive.';
$strNoExplain = 'Ne pas expliquer SQL';
$strNoFilesFoundInZip = 'Aucun fichier prsent dans l\'archive ZIP!';
$strNoFrames = 'L\'utilisation de phpMyAdmin est plus aise avec un navigateur <b>supportant les "frames"</b>.';
$strNoIndex = 'Aucune clef n\'est dfinie&nbsp;!';
$strNoIndexPartsDefined = 'Aucune colonne n\'a t dfinie pour cette clef&nbsp;!';
$strNoModification = 'Pas de modifications';
$strNone = 'aucune';
$strNo = 'Non';
$strNoOptions = 'Ce format ne comporte pas d\'options';
$strNoPassword = 'aucun mot de passe';
$strNoPermission = 'Le serveur web n\'a pas les permissions ncessaires pour enregistrer le fichier %s.';
$strNoPhp = 'Sans source PHP';
$strNoPrivileges = 'aucun privilge';
$strNoRights = 'Vous n\'tes pas autoris  accder  cette page';
$strNoRowsSelected = 'Aucun enregistrement n\'a t slectionn';
$strNoSpace = 'Espace-disque insuffisant pour enregistrer le fichier %s.';
$strNoTablesFound = 'Aucune table n\'a t trouve dans cette base.';
$strNoThemeSupport = 'Les thmes ne sont pas supports, veuillez vrifier votre configuration et/ou vos thmes dans le rpertoire %s.';
$strNotNumber = 'Ce n\'est pas un nombre !';
$strNotOK = 'en erreur';
$strNotSet = 'La table <b>%s</b> est absente ou non dfinie dans %s';
$strNoUsersFound = 'Il n\'y a aucun utilisateur';
$strNoValidateSQL = 'Ne pas valider SQL';
$strNull = 'Null';
$strNumberOfFields = 'Nombre de champs';
$strNumberOfTables = 'Nombre de tables';
$strNumSearchResultsInTable = '%s occurence(s) dans la table <i>%s</i>';
$strNumSearchResultsTotal = '<b>Total :</b> <i>%s</i> occurence(s)';
$strNumTables = 'Tables';

$strOK = 'OK';
$strOpenDocumentSpreadsheet = 'Tableur "Open Document"';
$strOpenDocumentText = 'Texte "Open Document"';
$strOpenNewWindow = 'Ouvrir une nouvelle fentre phpMyAdmin';
$strOperations = 'Oprations';
$strOperator = 'Oprateur';
$strOptimizeTable = 'Optimiser la table';
$strOptions = 'Options';
$strOr = 'Ou';
$strOverhead = 'Perte';
$strOverwriteExisting = 'craser les fichiers existants';

$strPageNumber = 'Page n:';
$strPagesToBeFlushed = 'Pages devant tre vides';
$strPaperSize = 'Taille du papier';
$strPartialImport = 'Importation partielle';
$strPartialText = 'Textes rduits';
$strPasswordChanged = 'Le mot de passe de %s a t chang.';
$strPasswordEmpty = 'Le mot de passe est vide';
$strPasswordHashing = 'Hachage du mot de passe';
$strPassword = 'Mot de passe';
$strPasswordNotSame = 'Les mots de passe doivent tre identiques';
$strPdfDbSchema = 'Schema de la base "%s" - Page %s';
$strPdfInvalidTblName = 'La table "%s" n\'existe pas !';
$strPdfNoTables = 'Pas de table !';
$strPDF = 'PDF';
$strPDFReportExplanation = '(Gnre un rapport contenant les donnes d\'une seule table)';
$strPDFReportTitle = 'Titre du rapport';
$strPerHour = 'par heure';
$strPerMinute = 'par minute';
$strPerSecond = 'par seconde';
$strPersian = 'perse';
$strPhoneBook = 'annuaire tlphonique';
$strPHP40203 = 'Vous utilisez PHP 4.2.3, et cette version a un srieux problme avec les caractres multi-octets (mbstring), tel que dcrit sur le rapport d\'anomalies 19404 chez PHP.  Il n\'est pas recommand d\'utiliser cette version de PHP avec phpMyAdmin.';
$strPhp = 'Crer source PHP';
$strPHPVersion = 'Version de PHP';
$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la cl primaire ou une cl unique';
$strPmaDocumentation = 'Documentation de phpMyAdmin';
$strPmaUriError = 'Le paramtre <tt>$cfg[\'PmaAbsoluteUri\']</tt> DOIT tre renseign dans votre fichier de configuration !';
$strPmaWiki = 'Wiki phpMyAdmin';
$strPolish = 'polonais';
$strPortrait = 'Portrait';
$strPos1 = 'Dbut';
$strPrevious = 'Prcdent';
$strPrimaryKeyHasBeenDropped = 'La cl primaire a t efface';
$strPrimaryKeyName = 'Le nom d\'une clef primaire doit tre PRIMARY&nbsp;!';
$strPrimaryKeyWarning = '("PRIMARY" <b>doit et ne peut tre</b> que le nom d\'une clef primaire&nbsp;!)';
$strPrimary = 'Primaire';
$strPrint = 'Imprimer';
$strPrintViewFull = 'Version imprimable (avec textes complets)';
$strPrintView = 'Version imprimable';
$strPrivDescAllPrivileges = 'Tous les privilges sauf GRANT.';
$strPrivDescAlter = 'Permission de modifier la structure des tables existantes.';
$strPrivDescAlterRoutine = 'Permission de modifier et de supprimer des procdures stockes.';
$strPrivDescCreateDb = 'Permission de crer des bases de donnes et des tables.';
$strPrivDescCreateRoutine = 'Permission de crer des procdures stockes.';
$strPrivDescCreateTbl = 'Permission de crer des tables.';
$strPrivDescCreateTmpTable = 'Permission de crer des tables temporaires.';
$strPrivDescCreateUser = 'Permission de crer, supprimer et renommer des comptes utilisateurs';
$strPrivDescCreateView = 'Permission de crer des vues.';
$strPrivDescDelete = 'Permission de dtruire des donnes';
$strPrivDescDropDb = 'Permission d\'effacer des bases de donnes et des tables.';
$strPrivDescDropTbl = 'Permission d\'effacer des tables.';
$strPrivDescExecute5 = 'Permission d\'excuter des procdures stockes';
$strPrivDescExecute = 'Permission d\'excuter des procdures. Non effectif dans cette version de MySQL.';
$strPrivDescFile = 'Permission d\'importer et d\'exporter des donnes  partir de / dans des fichiers.';
$strPrivDescGrant = 'Permission d\'ajouter des utilisateurs et des privilges sans avoir besoin de recharger les privilges.';
$strPrivDescIndex = 'Permission de crer et d\'effacer des index.';
$strPrivDescInsert = 'Permission d\'ajouter et de remplacer des donnes';
$strPrivDescLockTables = 'Permission de verrouiller des enregistrements dans le fil courant (unit d\'excution).';
$strPrivDescMaxConnections = 'Limite du nombre de nouvelles connexions qu\'un utilisateur peut dmarrer, par heure.';
$strPrivDescMaxQuestions = 'Limite du nombre de requtes qu\'un utilisateur peut envoyer au serveur, par heure.';
$strPrivDescMaxUpdates = 'Limite du nombre de commandes changeant une table ou base de donnes, qu\'un utilisateur peut excuter, par heure.';
$strPrivDescMaxUserConnections = 'Limite le nombre de connexions simultanes autorises pour un utilisateur.';
$strPrivDescProcess3 = 'Permission de dtruire les processus de d\'autres utilisateurs.';
$strPrivDescProcess4 = 'Permission de voir le texte complet des requtes, dans la liste des processus.';
$strPrivDescReferences = 'Non effectif dans cette version de MySQL.';
$strPrivDescReload = 'Permission de recharger les rglages du serveur, et de vidanger la mmoire cache.';
$strPrivDescReplClient = 'Permission de demander o sont les matres et les esclaves (systme de duplication).';
$strPrivDescReplSlave = 'Ncessaire pour les esclaves (systme de duplication).';
$strPrivDescSelect = 'Permission de lire des donnes.';
$strPrivDescShowDb = 'Permission de voir la liste complte des noms de bases de donnes.';
$strPrivDescShowView = 'Permission d\'excuter SHOW CREATE VIEW.';
$strPrivDescShutdown = 'Permission d\'arrter le serveur MySQL.';
$strPrivDescSuper = 'Permission de se connecter, mme si le nombre maximal de connexions permises a t atteint; ceci est requis pour la plupart des oprations de type administratif, par exemple les changements de variables globales ou la destruction de processus.';
$strPrivDescUpdate = 'Permission de changer des donnes.';
$strPrivDescUsage = 'Pas de privilges';
$strPrivileges = 'Privilges';
$strPrivilegesReloaded = 'Les privilges ont t rechargs.';
$strProcedures = 'Procdures';
$strProcesses = 'Processus';
$strProcesslist = 'Liste des processus';
$strProfiling = 'Profilage';
$strProtocolVersion = 'Version du protocole';
$strPutColNames = 'Afficher les noms de champ en premire ligne';

$strQBEDel = 'Effacer';
$strQBEIns = 'Ajouter';
$strQBE = 'Requte';
$strQueryCache = 'Cache des requtes';
$strQueryFrame = 'Fentre SQL';
$strQueryOnDb = 'Requte SQL sur la base <b>%s</b>&nbsp;:';
$strQueryResultsOperations = 'Oprations sur les rsultats de la requte';
$strQuerySQLHistory = 'Historique SQL';
$strQueryStatistics = '<b>Statistiques sur les requtes</b>: Depuis son dmarrage, %s requtes ont t envoyes au serveur.';
$strQueryTime = 'traitement: %01.4f sec.';
$strQueryType = 'Type de requte';
$strQueryWindowLock = 'Ne pas craser cette requte depuis une autre fentre';

$strReadRequests = 'Requtes de lecture';
$strReceived = 'Reu';
$strRecommended = 'recommand';
$strRecords = 'Enregistrements';
$strReferentialIntegrity = 'Vrifier l\'intgrit rfrentielle';
$strRefresh = 'Actualiser';
$strRelationalSchema = 'Schma relationnel';
$strRelationDeleted = 'Relation supprime';
$strRelationNotWorking = 'Certaines fonctionnalits ayant trait aux tables relies sont dsactives. Pour une analyse du problme, cliquez %sici%s.';
$strRelationsForTable = 'RELATIONS POUR LA TABLE';
$strRelations = 'Relations';
$strRelationView = 'Gestion des relations';
$strReloadingThePrivileges = 'Chargement des privilges en cours.';
$strReloadPrivileges = 'Recharger les privilges';
$strReload = 'Recharger';
$strRemoveSelectedUsers = 'Effacer les utilisateurs slectionns.';
$strRenameDatabaseOK = 'La base de donnes %s a t renomme en %s';
$strRenameTable = '<b>Changer le nom</b> de la table pour';
$strRenameTableOK = 'La table %s se nomme maintenant %s';
$strRepairTable = 'Rparer la table';
$strReplaceNULLBy = 'Remplacer NULL par';
$strReplaceTable = 'Remplacer les donnes de la table avec le fichier';
$strReplication = 'Rplication';
$strReset = 'Rinitialiser les valeurs';
$strResourceLimits = 'Limites de ressources.';
$strRestartInsertion = 'Recommencer l\'insertion avec %s lignes';
$strReType = 'Entrer  nouveau';
$strRevokeAndDeleteDescr = 'Les utilisateurs auront le privilege "USAGE", jusqu\' ce que les privilges soient rechargs.';
$strRevokeAndDelete = 'Effacer tous les privilges de ces utilisateurs, puis les effacer.';
$strRevokeMessage = 'Vous avez rvoqu les privilges pour %s';
$strRevoke = 'Rvoquer';
$strRomanian = 'roumain';
$strRoutineReturnType = 'Type retourn';
$strRoutines = 'Procdures stockes';
$strRowLength = 'Longueur enr.';
$strRows = 'Enregistrements';
$strRowsFrom = 'enregistrement(s)  partir de l\'enregistrement n';
$strRowSize = ' Taille enr. ';
$strRowsModeFlippedHorizontal = 'horizontal (en-ttes pivots)';
$strRowsModeHorizontal = 'horizontal';
$strRowsModeOptions = 'en mode %s et rpter les en-ttes  chaque groupe de %s';
$strRowsModeVertical = 'vertical';
$strRowsStatistic = 'Statistiques';
$strRunning = 'sur le serveur %s';
$strRunQuery = 'Excuter la requte';
$strRunSQLQuery = 'Excuter une ou des <b>requtes</b> sur la base %s';
$strRunSQLQueryOnServer = 'Excuter une ou des requtes SQL sur le serveur %s';
$strRussian = 'russe';

$strSaveOnServer = 'Sauvegarder sur le serveur dans le rpertoire %s';
$strSavePosition = 'Sauvegarder la position';
$strSave = 'Sauvegarder';
$strScaleFactorSmall = 'Veuillez augmenter l\'chelle car le schma dborde la page';
$strSearchFormTitle = 'Effectuer une nouvelle recherche dans la base de donnes';
$strSearchInTables = 'Dans la(les) table(s) :';
$strSearchNeedle = 'Mot(s) ou Valeur  rechercher (passe-partout: "%") :';
$strSearchOption1 = 'au moins un mot';
$strSearchOption2 = 'tous les mots';
$strSearchOption3 = 'phrase exacte';
$strSearchOption4 = 'expression rgulire';
$strSearch = 'Rechercher';
$strSearchResultsFor = 'Rsultats de la recherche de "<i>%s</i>" %s :';
$strSearchType = 'Type de recherche :';
$strSecretRequired = 'Vous devez ajouter dans le fichier de configuration une phrase de passe secrte (blowfish_secret).';
$strSelectADb = 'Choisissez une base de donnes';
$strSelectAll = 'Tout slectionner';
$strSelectBinaryLog = 'Slectionnez le log binaire  consulter';
$strSelectFields = 'Choisir les champs  afficher (au moins un)';
$strSelectForeignKey = 'Choisissez la cl trangre';
$strSelectNumRows = 'dans la requte';
$strSelectReferencedKey = 'Slectionnez la cl rfrence';
$strSelectTables = 'Choisissez les tables';
$strSend = 'Transmettre';
$strSent = 'Envoy';
$strServerChoice = 'Choix du serveur';
$strServerNotResponding = 'Le serveur ne rpond pas.';
$strServer = 'Serveur';
$strServers = 'Serveurs';
$strServerStatusDelayedInserts = 'Insertions avec dlais';
$strServerStatus = 'Informations sur le serveur';
$strServerStatusUptime = 'Ce serveur MySQL fonctionne depuis %s. Il a dmarr le %s.';
$strServerTabVariables = 'Variables';
$strServerTrafficNotes = '<b>Statistiques sur le trafic</b>: Ce tableau indique le trafic rseau observ sur ce serveur MySQL depuis son dmarrage.';
$strServerVars = 'Variables et rglages du serveur';
$strServerVersion = 'Version du serveur';
$strSessionStartupErrorGeneral = 'Erreur lors du dmarrage de la session, veuillez vrifier les erreurs indiques par PHP ou dans le fichier tmoin du serveur web, et configurer PHP correctement.';
$strSessionValue = 'Valeur pour la session';
$strSetEnumVal = 'Les diffrentes valeurs des champs de type enum/set sont  spcifier sous la forme \'a\',\'b\',\'c\'...<br />Pour utiliser un caractre "\\" ou "\'" dans l\'une de ces valeurs, faites-le prcder du caractre d\'chappement "\\" (par exemple \'\\\\xyz\' ou \'a\\\'b\').';
$strShow = 'Afficher';
$strShowAll = 'Tout afficher';
$strShowColor = 'Couleurs';
$strShowDatadictAs = 'Orientation du dictionnaire:';
$strShowFullQueries = 'Afficher les requtes compltes';
$strShowGrid = 'Grille';
$strShowHideLeftMenu = 'Montrer/cacher le menu de gauche';
$strShowingBookmark = 'Affichage du signet';
$strShowingPhp = 'Affichage du code PHP';
$strShowingRecords = 'Affichage des enregistrements';
$strShowingSQL = 'Affichage de la requte SQL';
$strShowOpenTables = 'Montrer les tables ouvertes';
$strShowPHPInfo = 'Afficher les informations relatives  PHP';
$strShowSlaveHosts = 'Montrer les serveurs esclaves';
$strShowSlaveStatus = 'Montrer l\'tat des serveurs esclaves';
$strShowStatusBinlog_cache_disk_useDescr = 'Le nombre de transactions qui ont utilis la cache temporaire du log binaire mais qui ont excd la valeur de binlog_cache_size et ont utilis un fichier temporaire pour stocker les noncs de la transaction.';
$strShowStatusBinlog_cache_useDescr = 'Le nombre de transactions qui ont utilis la cache temporaire du log binaire.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'Le nombre de tables temporaires sur disque cres automatiquement par le serveur lors de l\'excution d\'noncs. Si la valeur du paramtre Created_tmp_disk_tables est trop grande, augmentez la valeur de tmp_table_size afin que les tables temporaires soient maintenues en mmoire au lieu d\'tre sur disque.';
$strShowStatusCreated_tmp_filesDescr = 'Le nombre de fichiers temporaires crs par mysqld.';
$strShowStatusCreated_tmp_tablesDescr = 'Le nombre de tables temporaires en mmoire cres automatiquement par le serveur lors de l\'excution d\'noncs.';
$strShowStatusDelayed_errorsDescr = 'Le nombre d\'enregistrements crits avec INSERT DELAYED pour lesquels une erreur est survenue (probablement un doublon sur la cl).';
$strShowStatusDelayed_insert_threadsDescr = 'Le nombre de fils d\'excution utiliss pour INSERT DELAYED. Un fil est utilis pour chacune des tables sur lesquelles un INSERT DELAYED a lieu.';
$strShowStatusDelayed_writesDescr = 'Le nombre d\'enregistrements crits via INSERT DELAYED.';
$strShowStatusFlush_commandsDescr  = 'Le nombre de commandes FLUSH excutes.';
$strShowStatusHandler_commitDescr = 'Le nombre de commandes COMMIT internes.';
$strShowStatusHandler_deleteDescr = 'Le nombre de fois qu\'un enregistrement a t supprim d\'une table.';
$strShowStatusHandler_discoverDescr = 'Le serveur MySQL peut demander au moteur de donnes NDB Cluster s\'il connat une table portant un certain nom. Ceci est appel &quot;dcouverte&quot;. Ce paramtre indique le nombre de fois que des tables ont t dcouvertes.';
$strShowStatusHandler_read_firstDescr = 'Le nombre de fois que la premire entre a t lue depuis un index. Si c\'est lev, ceci suggre que le serveur effectue beaucoup de parcours complets d\'un index; par exemple, SELECT coll FROM foo, en assumant que coll est une colonne indexe.';
$strShowStatusHandler_read_keyDescr = 'Le nombre de requtes pour lire un enregistrement via une cl. Si lev, c\'est une bonne indication que vos tables sont correctement indexes.';
$strShowStatusHandler_read_nextDescr = 'Le nombre de requtes de lecture du prochain enregistrement, en ordre de cl. Ceci est augment si vous interrogez une colonne indexe avec un critre de fourchette ou si vous parcourez l\'index.';
$strShowStatusHandler_read_prevDescr = 'Le nombre de requtes de lecture de l\'enregistrement prcdent, en ordre de cl. Utilis surtout pour optimiser ORDER BY ... DESC';
$strShowStatusHandler_read_rndDescr = 'Le nombre de requtes de lecture d\'un enregistrement base sur une position fixe. Ce nombre est lev si vous faites de nombreuses requtes qui ncessitent de trier les rsultats. Vous avez probablement un grand nombre de requtes qui demandent  MySQL de parcourir des tables en entier, ou vous avez des jointures qui n\'utilisent pas correctement les cls.';
$strShowStatusHandler_read_rnd_nextDescr = 'Le nombre de requtes de lecture du prochaine enregistrement dans le fichier. lev si vous faites plusieurs parcours de tables. Ceci suggre que vos tables ne sont pas correctement indexes ou que vos requtes ne sont pas crites de faon  tirer parti des index que vous avez dfinis.';
$strShowStatusHandler_rollbackDescr = 'Le nombre d\'noncs ROLLBACK internes.';
$strShowStatusHandler_updateDescr = 'Le nombre de requtes de mise  jour d\'enregistrements.';
$strShowStatusHandler_writeDescr = 'Le nombre de requtes d\'insertion d\'enregistrements.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'Le nombre de pages contenant des donnes.';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'Le nombre de pages contenant des donnes "dirty"';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'Le nombre de pages de mmoire-tampon qui ont t effaces.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'Le nombre de pages libres';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'Le nombre de pages dans la rserve InnoDB qui sont actuellement en train d\'tre lues ou crites, ou qui ne peuvent tre supprimes pour une autre raison.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'Le nombre de pages occupes car elles ont t dalloues en raison de verrous sur les enregistrements. Cette valeur peut galement tre calcule comme suit: Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Taille totale de la rserve, en pages.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'Le nombre de lectures discontinues effectues par InnoDB. Ceci survient lorsqu\'une requte doit balayer une large portion de table en ordre discontinu.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'Le nombre de lectures squentielles effectues par InnoDB. Ceci survient quand InnoDB fait un parcours squentiel intgral de la table.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'Le nombre de requtes de lectures "logiques" effectues par InnoDB.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'Le nombre de lectures que InnoDB n\'a pu faire  partir de la rserve, menant  une lecture directe d\'une page.';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normalement, l\'criture dans la rserve InnoDB se passe en arrire-plan. Cependant, s\'il est ncessaire de lire ou de crer une page et qu\'aucune page n\'est disponible, InnoDB doit attendre que des pages soient libres. Ceci compte le nombre de fois qu\'une telle attente a t ncessaire. Si la taille de la rserve est adquate, cette valeur devrait tre petite.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'Le nombre d\'critures faites dans la rserve InnoDB.';
$strShowStatusInnodb_data_fsyncsDescr = 'Le nombre d\'oprations fsync() faites jusqu\' prsent.';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'Le nombre d\'oprations fsync() actuellement en attente.';
$strShowStatusInnodb_data_pending_readsDescr = 'Le nombre actuel de lectures en attente.';
$strShowStatusInnodb_data_pending_writesDescr = 'Le nombre actuel d\'critures en attente.';
$strShowStatusInnodb_data_readDescr = 'La quantit d\'octets lus jusqu\' prsent.';
$strShowStatusInnodb_data_readsDescr = 'Le nombre total de lectures de donnes.';
$strShowStatusInnodb_data_writesDescr = 'Le nombre total d\'critures de donnes.';
$strShowStatusInnodb_data_writtenDescr = 'La quantit d\'octets crits jusqu\' prsent.';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'Le nombre de pages utilises pour des critures "doublewrite".';
$strShowStatusInnodb_dblwr_writesDescr = 'Le nombre d\'critures "doublewrite" effectues.';
$strShowStatusInnodb_log_waitsDescr = 'Le nombre d\'attentes en raison d\'un tampon du fichier tmoin trop petit; il fallait attendre qu\'il se libre avant de continuer.';
$strShowStatusInnodb_log_write_requestsDescr = 'Le nombre de requtes d\'critures sur le fichier tmoin.';
$strShowStatusInnodb_log_writesDescr = 'Le nombre d\'critures physiques au fichier tmoin.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'Le nombre d\'critures fsync() sur le fichier tmoin.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'Le nombre de fsync() du fichier tmoin en attente.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'Le nombre d\'critures du fichier tmoin en attente.';
$strShowStatusInnodb_os_log_writtenDescr = 'Le nombre d\'octets crits sur le fichier tmoin.';
$strShowStatusInnodb_pages_createdDescr = 'Le nombre de pages cres.';
$strShowStatusInnodb_page_sizeDescr = 'La taille de page InnoDB telle que compile (16 Ko par dfaut). Plusieurs valeurs sont comptes par page; la taille de page leur permet d\'tre facilement converties en octets.';
$strShowStatusInnodb_pages_readDescr = 'Le nombre de pages lues.';
$strShowStatusInnodb_pages_writtenDescr = 'Le nombre de pages crites.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'Le nombre de verrous d\'enregistrements actuellement en attente.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'Le temps d\'attente moyen pour acqurir un verrou, en millisecondes.';
$strShowStatusInnodb_row_lock_timeDescr = 'Le temps total utilis pour acqurir un verrou, en millisecondes.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'Le temps d\'attente maximum pour acqurir un verrou, en millisecondes.';
$strShowStatusInnodb_row_lock_waitsDescr = 'Le nombre de fois qu\'on a d attendre pour un verrou.';
$strShowStatusInnodb_rows_deletedDescr = 'Le nombre d\'enregistrements supprims des tables InnoDB.';
$strShowStatusInnodb_rows_insertedDescr = 'Le nombre d\'enregistrements insrs dans des tables InnoDB.';
$strShowStatusInnodb_rows_readDescr = 'Le nombre d\'enregistrements lus dans des tables InnoDB.';
$strShowStatusInnodb_rows_updatedDescr = 'Le nombre d\'enregistrements mis  jour dans des tables InnoDB.';
$strShowStatusKey_blocks_not_flushedDescr = 'Le nombre de blocs de cls dans la cache de cls qui ont t modifis mais pas encore transfrs sur disque.';
$strShowStatusKey_blocks_unusedDescr = 'Le nombre de blocs inutiliss dans la cache de cls. Vous pouvez utiliser cette valeur pour dterminer la proportion de la cache de cls qui est utilise.';
$strShowStatusKey_blocks_usedDescr = 'Le nombre maximum de blocs qui ont t utiliss en mme temps dans la cache de cls.';
$strShowStatusKey_read_requestsDescr = 'Le nombre de requtes de lecture d\'un bloc de cls depuis la cache.';
$strShowStatusKey_readsDescr = 'Le nombre de lectures physiques d\'un bloc de cls depuis le disque. Si cette valeur est leve, la taille de votre mmoire tampon de cls est trop petite. Le taux d\'chec de la cache peut tre calcul par "Key reads/Key read requests".';
$strShowStatusKey_write_requestsDescr = 'Le nombre de requtes en vue d\'crire un bloc de cl dans la cache.';
$strShowStatusKey_writesDescr = 'Le nombre d\'critures physiques d\'un bloc de cls vers le disque.';
$strShowStatusLast_query_costDescr = 'Le cot total de la dernire requte compile, tel que calcul par l\'optimiseur de requtes. Utile pour comparer le cot de diverses stratgies pour une mme requte. La valeur de 0 indique qu\'aucune requte n\'a encore t compile.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'Le nombre d\'enregistrements en attente d\'criture (INSERT DELAYED).';
$strShowStatusOpened_tablesDescr = 'Le nombre tables qui ont t ouvertes. Si trop lev, votre cache de table est probablement trop petite.';
$strShowStatusOpen_filesDescr = 'Le nombre de fichiers qui sont ouverts.';
$strShowStatusOpen_streamsDescr = 'Le nombre de flux de donnes qui sont ouverts.';
$strShowStatusOpen_tablesDescr = 'Le nombre de tables qui sont ouvertes.';
$strShowStatusQcache_free_blocksDescr = 'Le nombre de blocs de mmoire libre dans la cache de requtes.';
$strShowStatusQcache_free_memoryDescr = 'La quantit de mmoire libre dans la cache de requtes.';
$strShowStatusQcache_hitsDescr = 'Le nombre de succs dans la cache.';
$strShowStatusQcache_insertsDescr = 'Le nombre de requtes ajoutes  la cache.';
$strShowStatusQcache_lowmem_prunesDescr = 'Le nombre de requtes qui ont t retires de la cache pour librer de la mmoire afin de mettre en cache de nouvelles requtes. Peut tre utilis afin de peaufiner la taille de la cache. La stratgie utilise pour dterminer quelles requtes seront retires est LRU (least recently used).';
$strShowStatusQcache_not_cachedDescr = 'Le nombre de requtes non en cache (impossible  placer en cache, ou non cache en raison du paramtre query_cache_type).';
$strShowStatusQcache_queries_in_cacheDescr = 'Le nombre de requtes enregistres dans la cache.';
$strShowStatusQcache_total_blocksDescr = 'Le nombre total de blocs dans la cache de requtes.';
$strShowStatusReset = 'Rinitialiser';
$strShowStatusRpl_statusDescr = 'L\'tat de la rplication sans chec (pas encore implante).';
$strShowStatusSelect_full_joinDescr = 'Le nombre de jointures qui n\'ont pas utilis d\'index. Si cette valeur est suprieure  0, vrifiez soigneusement les indexes de vos tables.';
$strShowStatusSelect_full_range_joinDescr = 'Le nombre de jointures qui ont utilis une recherche par plage sur une table de rfrence.';
$strShowStatusSelect_range_checkDescr = 'Le nombre de jointures sans cls qui vrifient l\'utilisation de cl  chaque enregistrement. (Si ceci est suprieur  0, vrifiez soigneusement les indexes de vos tables.)';
$strShowStatusSelect_rangeDescr = 'Le nombre de jointures qui ont utilis des plages sur la premire table. (Normalement non critique mme si cette valeur est leve.)';
$strShowStatusSelect_scanDescr = 'Le nombre de jointures qui ont ncessit le parcours complet de la premire table.';
$strShowStatusSlave_open_temp_tablesDescr = 'Le nombre de tables temporaires actuellement ouvertes par le fil d\'excution SQL de l\'esclave.';
$strShowStatusSlave_retried_transactionsDescr = 'Nombre de fois (depuis le dmarrage) que le fil d\'excution SQL de l\'esclave a envoy  nouveau des transactions.';
$strShowStatusSlave_runningDescr = 'Ceci est  ON si ce serveur est un esclave connect  un matre.';
$strShowStatusSlow_launch_threadsDescr = 'Le nombre de fils d\'excution dont le temps de cration a excd slow_launch_time secondes.';
$strShowStatusSlow_queriesDescr = 'Le nombre de requtes dont le temps d\'excution a excd long_query_time secondes.';
$strShowStatusSort_merge_passesDescr = 'Le nombre d\'oprations de fusion effectues par l\'algorithme de tri. Si ce nombre est lev, augmentez la valeur du paramtre sort_buffer_size.'; 
$strShowStatusSort_rangeDescr = 'Le nombre de tri effectus avec des plages.';
$strShowStatusSort_rowsDescr = 'Le nombre d\'enregistrements tris.';
$strShowStatusSort_scanDescr = 'Le nombre de tri effectus via un parcours de la table.';
$strShowStatusTable_locks_immediateDescr = 'Le nombre de fois qu\'un verrou de table a t acquis immdiatement.';
$strShowStatusTable_locks_waitedDescr = 'Le nombre de fois qu\'un verrou de table n\'a pu tre acquis immdiatement, induisant un temps d\'attente. Si ce nombre est lev et que vous prouvez des problmes de performance, commencez par optimiser vos requtes, puis subdivisez vos tables ou encore utiliser la rplication.';
$strShowStatusThreads_cachedDescr = 'Le nombre de fils dans la cache des fils d\'excution. Si cette valeur est en rouge, vous devriez augmenter la taille de cette cache.'; 
$strShowStatusThreads_connectedDescr = 'Le nombre de connexions ouvertes actuellement.';
$strShowStatusThreads_createdDescr = 'Le nombre de fils d\'excution crs afin de grer les connexions. Si ce nombre est trop grand, vous pourriez augmenter la valeur du paramtre thread_cache_size. (Normalement, ceci ne procure pas une amlioration perceptible de la performance si votre serveur gre correctement les fils d\'excution.';
$strShowStatusThreads_runningDescr = 'Le nombre de fils d\'excution non suspendus.';
$strShowTableDimension = 'Dimension des tables';
$strShowTables = 'Afficher les tables';
$strShowThisQuery = 'Rafficher la requte aprs excution';
$strSimplifiedChinese = 'chinois simplifi';
$strSingly = '( refaire aprs insertions/destructions)';
$strSize = 'Taille';
$strSkipQueries = 'Nombre d\'enregistrements (requtes)  ignorer  partir du dbut';
$strSlovak = 'slovaque';
$strSlovenian = 'slovne';
$strSmallBigAll = 'Agrandir/rduire tout';
$strSnapToGrid = 'Accrocher  la grille';
$strSocketProblem = '(ou l\'interface de connexion ("socket") vers le serveur MySQL local n\'est pas correctement configure)';
$strSortByKey = 'Trier sur l\'index';
$strSorting = 'Mcanisme de tri';
$strSort = 'Tri';
$strSpaceUsage = 'Espace utilis';
$strSpanish = 'espagnol';
$strSplitWordsWithSpace = 'Sparer les mots par un espace (" ").';
$strSQLCompatibility = 'Mode de compatibilit SQL';
$strSQLExportType = 'Type d\'exportation';
$strSQLParserBugMessage = 'Il semble que vous ayiez trouv une anomalie dans l\'analyseur syntaxique SQL. Veuillez examiner votre requte attentivement, et vrifier que vos apostrophes sont conformes. Il se pourrait aussi que vous ayiez charg un fichier dont le contenu binaire n\'est pas entre apostrophes.  Si vous avez accs  MySQL via son interface de commande en mode ligne, vous pouvez y essayer votre requte. Le message d\'erreur prsent plus bas pourrait vous indiquer la source du problme. En dernier recours, veuillez trouver la plus courte requte possible qui cause le problme, et soumettre un rapport d\'anomalie en incluant la section  couper:';
$strSQLParserUserError = 'Il semble qu\'il y ait une erreur dans votre requte SQL. Le message ci-bas peut vous aider  en trouver la cause.';
$strSQLQuery = 'requte SQL';
$strSQLResult = 'Rsultat de la requte SQL';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Identificateur invalide';
$strSQPBugUnclosedQuote = 'Apostrophe non ferm';
$strSQPBugUnknownPunctuation = 'Ponctuation invalide';
$strStandInStructureForView = 'Doublure de structure pour la vue';
$strStatCheckTime = 'Dernire vrification';
$strStatCreateTime = 'Cration';
$strStatement = 'Information';
$strStatisticsOverrun = 'Sur un serveur surcharg, la capacit des compteurs d\'octets peut tre dpasse, auquel cas les statistiques rapportes par MySQL peuvent tre inexactes.';
$strStatUpdateTime = 'Dernire modification';
$strStatus = 'tat';
$strStorageEngine = 'Moteur de stockage';
$strStorageEngines = 'Moteurs de stockage';
$strStrucCSV = 'CSV';
$strStrucData = 'Structure et donnes';
$strStrucExcelCSV = 'CSV pour MS Excel';
$strStrucNativeExcel = 'Donnes MS Excel (format natif)';
$strStrucOnly = 'Structure seule';
$strStructPropose = 'Suggrer des optimisations quant  la structure de la table';
$strStructureForView = 'Structure de la vue';
$strStructure = 'Structure';
$strSubmit = 'Excuter';
$strSuccess = 'Votre requte SQL a t excute avec succs';
$strSum = 'Somme';
$strSwedish = 'sudois';
$strSwitchToDatabase = 'Aller  la base de donnes copie';
$strSwitchToTable = 'Aller  la table copie';

$strTableAlreadyExists = 'La table %s existe dj!';
$strTableComments = 'Commentaires sur la table';
$strTableEmpty = 'Le nom de la table est vide';
$strTableHasBeenDropped = 'La table %s a t efface';
$strTableHasBeenEmptied = 'La table %s a t vide';
$strTableHasBeenFlushed = 'La table %s a t recharge';
$strTableIsEmpty = 'La table semble vide!';
$strTableMaintenance = '<b>Maintenance</b> de la table';
$strTableName = 'Nom de la table';
$strTableOfContents = 'Table des matires';
$strTableOptions = '<b>Options</b> pour cette table';
$strTables = '%s table(s)';
$strTableStructure = 'Structure de la table';
$strTable = 'Table';
$strTakeIt = 'utiliser celui-ci';
$strTblPrivileges = 'Privilges spcifiques  une table';
$strTempData = 'Donnes temporaires';
$strTextAreaLength = 'Il est possible que ce champ<br />ne soit pas ditable<br />en raison de sa longueur';
$strThai = 'tha';
$strThemeDefaultNotFound = 'Thme par dfaut %s inexistant!';
$strThemeNoPreviewAvailable = 'Prvisualisation non disponible.';
$strThemeNotFound = 'Thme %s inexistant!';
$strThemeNoValidImgPath = 'Chemin des images inexistant pour le thme %s!';
$strThemePathNotFound = 'Chemin non trouv pour le thme %s!';
$strTheme = 'Thme / Style';
$strThisHost = 'Ce serveur';
$strThreads = 'Fils d\'excution';
$strThreadSuccessfullyKilled = 'Le processus %s a t limin.';
$strTime = 'Dure';
$strTimeoutInfo = 'L\'importation prcdente a chou en raison du temps; retransmettez et le traitement reprendra  la position %d.';
$strTimeoutNothingParsed = 'Cependant lors du dernier traitement, aucune section n\a t analyse; ceci signifie que phpMyAdmin ne pourra terminer cette importation,  moins que la limite de temps de PHP ne soit augmente';
$strTimeoutPassed = 'La limite de temps a t atteinte; si vous voulez terminer l\'importation, soumettez  nouveau le mme fichier et l\'importation continuera.';
$strToFromPage = 'de/vers la page';
$strToggleScratchboard = 'diteur visuel';
$strToggleSmallBig = 'Bascule agrandir/rduire';
$strToSelectRelation = 'Pour slectionner un lien, cliquez :';
$strTotal = 'total';
$strTotalUC = 'Total';
$strTraditionalChinese = 'chinois traditionnel';
$strTraditionalSpanish = 'espagnol traditionnel';
$strTraffic = 'Trafic';
$strTransactionCoordinator = 'Coordonnateur des transactions';
$strTransformation_application_octetstream__download = 'Affiche un lien pour tlcharger le contenu binaire d\'une colonne. La premire option est le nom du fichier binaire. La seconde option est le nom de la colonne contenant le nom du fichier. Si vous utilisez la seconde option, veuillez laisser la premire option vide.';
$strTransformation_application_octetstream__hex = 'Affiche une reprsentation hexadcimale des donnes. Le premier paramtre est optionnel et spcifie combien d\'espaces seront ajouts.';
$strTransformation_image_jpeg__inline = 'Affiche une image timbre-poste cliquable; les options sont: largeur,hauteur en pixels (conserve le rapport original)';
$strTransformation_image_jpeg__link = 'Affiche un lien vers cette image';
$strTransformation_image_png__inline = 'Voir image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Affiche un champ TIME, TIMESTAMP, DATETIME ou un champ numrique contenant une valeur TIMESTAMP UNIX en tant que date formate. La premire option est le dcalage (en heures)  ajouter (par dfaut, 0). La seconde option sert  indiquer le format de date ou d\'heure. La troisime option dtermine si vous voulez la date locale ("local") ou UTC ("utc"). Pour le format "local", le second paramtre utilise le format de la fonction PHP strftime() et pour le format "utc", il utilise la fonction gmdate().';
$strTransformation_text_plain__external = '(Linux seulement) Excute un programme externe et lui envoit le contenu du champ via l\'entre standard. Puis capture la sortie standard de ce programme externe. Le programme par dfaut est tidy, pour un affichage embelli du code HTML.  Pour des raisons de scurit, vous devez diter le script libraries/transformations/text_plain__external.inc.php et y insrer les noms de programme externe possibles. La premire option est le numro du programme que vous voulez utiliser, la seconde option contient les paramtres pour ce programme. En troisime option, une valeur de 1 va convertir le rsultat avec la fonction htmlspecialchars() (par dfaut, 1). En option 4, une valeur de 1 va ajouter NOWRAP  la cellule affiche (par dfaut, 1).';
$strTransformation_text_plain__formatted = 'Prserve le contenu original du champ, sans ajout de caractres d\'chappement.';
$strTransformation_text_plain__imagelink = 'Affiche une image et un lien, le champ contient le nom du fichier; en premire option, un prfixe comme "http://domaine.com/", en seconde option, la largeur en pixels, en troisime option la hauteur en pixels.';
$strTransformation_text_plain__link = 'Affiche un lien, le champ contient le nom du fichier; en premire option, un prfixe comme "http://domaine.com/", en seconde option, un titre pour le lien.';
$strTransformation_text_plain__sql = 'Affiche le texte comme une requte SQL avec embellissement de la syntaxe.';
$strTransformation_text_plain__substr = 'N\'affiche qu\'une partie du champ. En premire option, la position de dpart (par dfaut, 0). En seconde option, le nombre de caractres  afficher (par dfaut, le reste). En troisime option, des caractres  afficher  la fin du texte (par dfaut: "...").';
$strTriggers = 'Dclencheurs';
$strTruncateQueries = 'Afficher les requtes tronques';
$strTurkish = 'turc';
$strType = 'Type';

$strUkrainian = 'ukrainien';
$strUncheckAll = 'Tout dcocher';
$strUnicode = 'Unicode';
$strUnique = 'Unique';
$strUnknown = 'inconnu';
$strUnselectAll = 'Tout dslectionner';
$strUnsupportedCompressionDetected = 'Vous avez tent d\'importer un fichier dont le mode de compression (%s) n\'est pas support par votre configuration PHP ou est dsactiv dans celle-ci.';
$strUpdatePrivMessage = 'Vous avez modifi les privilges pour %s.';
$strUpdateProfileMessage = 'Le profil a t modifi.';
$strUpdateQuery = 'Mise--jour de la requte';
$strUpdComTab = 'La documentation indique comment mettre  jour votre table Column_comments';
$strUpgrade = 'Vous devriez utiliser %s en version %s ou plus rcente.';
$strUploadErrorCantWrite = 'Erreur lors de l\'criture du fichier sur disque.';
$strUploadErrorExtension = 'Tlchargement arrt par l\'extension.';
$strUploadErrorFormSize = 'La taille du fichier tlcharg dpasse la limite permise par la directive MAX_FILE_SIZE prsente dans le formulaire HTML.';
$strUploadErrorIniSize = 'La taille du fichier tlcharg dpasse la limite permise par la directive upload_max_filesize de php.ini.';
$strUploadErrorNoTempDir = 'Rpertoire temporaire manquant.';
$strUploadErrorPartial = 'Le fichier n\'a t que partiellement tlcharg.';
$strUploadErrorUnknown = 'Erreur inconnue durant le tlchargement.';
$strUploadLimit = 'Vous avez probablement tent de tlcharger un fichier trop volumineux. Veuillez vous rfrer  la %sdocumentation%s pour des faons de contourner cette limite.';
$strUploadsNotAllowed = 'Les tlchargements vers ce serveur ne sont pas permis.';
$strUsage = 'Espace';
$strUseBackquotes = 'Protger les noms des tables et des champs par des&nbsp;"`"';
$strUsedPhpExtensions = 'Extensions PHP utilises';
$strUseHostTable = 'Utiliser la table Host';
$strUserAlreadyExists = 'L\'utilisateur %s existe dj!';
$strUserEmpty = 'Le nom d\'utilisateur est vide';
$strUserName = 'Nom d\'utilisateur';
$strUserNotFound = 'L\'utilisateur choisi n\'existe pas dans la table des privilges';
$strUserOverview = 'Vue d\'ensemble des utilisateurs';
$strUsersDeleted = 'Les utilisateurs slectionns ont t effacs.';
$strUsersHavingAccessToDb = 'Utilisateurs ayant accs  &quot;%s&quot;';
$strUser = 'Utilisateur';
$strUseTabKey = 'Utilisez la tabulation pour aller d\'une valeur  l\'autre, ou CTRL+flches pour aller n\'importe o';
$strUseTables = 'Utiliser les tables';
$strUseTextField = 'Entrez une valeur';
$strUseThisValue = 'Utiliser cette valeur';

$strValidateSQL = 'Valider SQL';
$strValidatorError = 'Le validateur SQL n\'a pas pu tre initialis. Vrifiez que les extensions PHP ncessaires ont bien t installes (voir la %sdocumentation%s).';
$strValue = 'Valeur';
$strVar = 'Variable';
$strVersionInformation = 'Information de version';
$strViewDump = '<b>Afficher le schma</b> de la table';
$strViewDumpDatabases = 'Schma et/ou contenu des bases de donnes';
$strViewDumpDB = 'Schma et donnes de la base ';
$strViewHasBeenDropped = 'La vue %s a t supprime';
$strViewMaxExactCount = 'Cette vue comporte plus de %d enregistrements. Veuillez vous rfrer  la %sdocumentation%s.';
$strViewName = 'Nom de la vue';
$strView = 'Vue';

$strWebServerUploadDirectoryError = 'Le rpertoire de transfert est inaccessible';
$strWebServerUploadDirectory = 'rpertoire de transfert du serveur Web';
$strWelcome = 'Bienvenue  %s ';
$strWestEuropean = 'Europe de l\'ouest';
$strWildcard = 'passepartout';
$strWindowNotFound = 'La fentre principale n\'a pu tre mise  jour. Il est possible que vous l\'ayiez ferme, ou encore que votre navigateur bloque les mises  jour inter-fentres pour des raisons de scurit.';
$strWithChecked = 'Pour la slection :';
$strWriteRequests = 'Requtes d\'criture';
$strWrongUser = 'Erreur d\'utilisateur/mot de passe. Accs refus';

$strXML = 'XML';

$strYes = 'Oui';

$strZeroRemovesTheLimit = 'Note: Une valeur de 0 (zero) enlve la limite.';
$strZip = '"zipp"';

?>
